==> node-caniuse-lite_1.0.30001283%2Bdfsg%2B~1.0.1.orig.tar.xz: caniuse-lite-1.0.30001283/src/packer/feature.js <==
const path = require('path')
const fs = require('fs').promises
const t = require('@babel/types')
const R = require('ramda')

const generateCode = require('../lib/generateCode')
const getContentsFactory = require('../lib/getContents')
const moduleExports = require('../lib/moduleExports')
const stringifyObject = require('../lib/stringifyObject')
const statuses = require('../../dist/lib/statuses')
const supported = require('../../dist/lib/supported')
const fromEntries = require('../util/fromEntries')
const parseDecimal = require('../util/parseDecimal')
const browsers = require('../../data/browsers')
const versions = require('../../data/browserVersions')

const browsersInverted = R.invertObj(browsers)
const statusesInverted = R.invertObj(statuses)
const versionsInverted = R.invertObj(versions)

const base = path.join(
  path.dirname(require.resolve(`caniuse-db/data.json`)),
  `features-json`
)

const getContents = getContentsFactory(base)

const requireCall = moduleName =>
  t.callExpression(t.identifier('require'), [t.stringLiteral(moduleName)])

const featureIndex = R.compose(
  generateCode,
  t.program,
  R.of,
  moduleExports,
  t.objectExpression,
  R.map(({ name }) =>
    t.objectProperty(t.stringLiteral(name), requireCall(`./features/${name}`))
  )
)

const packSupport = R.compose(
  R.sum,
  R.map(
    R.ifElse(
      R.flip(R.has)(supported),
      R.flip(R.prop)(supported),
      R.compose(num => 2 ** num, R.add(6), parseDecimal, R.slice(1, Infinity))
    )
  ),
  R.split(' ')
)

module.exports = async function packFeature() {
  let features = await fs.readdir(base).then(getContents)

  await Promise.all(
    features.map(({ name, contents }) => {
      let packed = {}

      packed.A = fromEntries(
        Object.entries(contents.stats).map(([key, browser]) => {
          let supportData = fromEntries(
            Object.entries(browser).map(([version, support]) => [
              versionsInverted[version],
              packSupport(support)
            ])
          )

          let compacted = Object.entries(supportData).reduce(
            (min, [k, value]) => {
              if (!min[value]) {
                min[value] = k
              } else {
                min[value] += ` ${k}`
              }
              return min
            },
            {}
          )

          return [browsersInverted[key], compacted]
        })
      )
      packed.B = parseDecimal(statusesInverted[contents.status])
      packed.C = contents.title
      return fs.writeFile(
        path.join(__dirname, `../../data/features/${name}.js`),
        stringifyObject(packed)
      )
    })
  )

  return fs.writeFile(
    path.join(__dirname, '../../data/features.js'),
    featureIndex(features)
  )
}

==> node-caniuse-lite_1.0.30001373%2Bdfsg%2B~1.0.1.orig.tar.xz: caniuse-lite-1.0.30001373/src/packer/feature.js <==
const path = require('path')
const fs = require('fs').promises
const t = require('@babel/types')

const generateCode = require('../lib/generateCode')
const getContentsFactory = require('../lib/getContents')
const moduleExports = require('../lib/moduleExports')
const stringifyObject = require('../lib/stringifyObject')
const statuses = require('../../dist/lib/statuses')
const supported = require('../../dist/lib/supported')
const fromEntries = require('../util/fromEntries')
const invertObj = require('../util/invertObj')
const parseDecimal = require('../util/parseDecimal')
const sum = require('../util/sum')
const browsers = require('../../data/browsers')
const versions = require('../../data/browserVersions')

const browsersInverted = invertObj(browsers)
const statusesInverted = invertObj(statuses)
const versionsInverted = invertObj(versions)

const base = path.join(
  path.dirname(require.resolve(`caniuse-db/data.json`)),
  `features-json`
)

const getContents = getContentsFactory(base)

const requireCall = moduleName =>
  t.callExpression(t.identifier('require'), [t.stringLiteral(moduleName)])

function featureIndex(features) {
  let index = t.objectExpression(
    features.map(({ name }) =>
      t.objectProperty(t.stringLiteral(name), requireCall(`./features/${name}`))
    )
  )

  return generateCode([moduleExports(index)])
}

function packSupport(supportData) {
  return sum(
    supportData.split(' ').map(support => {
      if (support in supported) {
        return supported[support]
      }
      return 2 ** (6 + parseDecimal(support.slice(1)))
    })
  )
}

module.exports = async function packFeature() {
  let features = await fs.readdir(base).then(getContents)

  await Promise.all(
    features.map(({ name, contents }) => {
      let packed = {}

      packed.A = fromEntries(
        Object.entries(contents.stats).map(([key, browser]) => {
          let supportData = fromEntries(
            Object.entries(browser).map(([version, support]) => [
              versionsInverted[version],
              packSupport(support)
            ])
          )

          let compacted = Object.entries(supportData).reduce(
            (min, [k, value]) => {
              if (!min[value]) {
                min[value] = k
              } else {
                min[value] += ` ${k}`
              }
              return min
            },
            {}
          )

          return [browsersInverted[key], compacted]
        })
      )
      packed.B = parseDecimal(statusesInverted[contents.status])
      packed.C = contents.title
      return fs.writeFile(
        path.join(__dirname, `../../data/features/${name}.js`),
        stringifyObject(packed)
      )
    })
  )

  return fs.writeFile(
    path.join(__dirname, '../../data/features.js'),
    featureIndex(features)
  )
}
